==> bzutech-1.0.1.tar.gz: bzutech-1.0.1/bzutech/device/Device.py <==
from aiohttp import ClientSession
import asyncio
from ..sensor import Sensor
class Device:
    def __init__(self, chipid: int, token: str, dispname: str = "" ):
        self.chipid = chipid
        self.dispname = dispname
        self.httpheaders = {"Authorization": token} 
        self.sensores = {}

    async def _async_set_sensores(self):
        url = "https://back-prd.bzutech.com.br/dispositivos/canais-list/" + str(
            self.chipid
        )
        sensores = []
        client = ClientSession()
        
        async with client.get(url, headers = self.httpheaders) as resp:
            resposta = await resp.json()
            await client.close()
            for sensor in resposta:
                if sensor["ultima_medicao_sensor"] != None:
                    sensores.append(
                        Sensor
                        (
                            self.chipid,
                            sensor["sensor_nome"],
                            sensor["apelido_canal"],
                        )
                    )
            return sensores

    async def initialize(self):
        self.sensores = await self._async_set_sensores()
        flemis = {}
        for sensor in self.sensores:
            flemis[sensor.apelido] = sensor

        self.sensores = flemis

    def get_sensor_names(self):
        return list(self.sensores.keys())

    def get_sensor_names_on(self, port: str):
        sensores = []
        for sensor in self.get_sensor_names():
            if sensor[-1] == port:
                sensores.append()
        return sensores

    def get_readings(self, nome_sensor):
        asyncio.run(self.sensores[nome_sensor].get_leitura())

    def get_chipid(self):
        return self.chipid

==> bzutech-1.0.3.tar.gz: bzutech-1.0.3/bzutech/device/Device.py <==
from aiohttp import ClientSession
import asyncio
from ..sensor import Sensor
class Device:
    def __init__(self, chipid: int, token: dict, dispname: str = "" ):
        self.chipid = chipid
        self.dispname = dispname
        self.httpheaders = token
        self.sensores = {}

    async def _async_set_sensores(self):
        url = "https://back-prd.bzutech.com.br/dispositivos/canais-list/" + str(
            self.chipid
        )
        sensores = []
        client = ClientSession()
        
        async with client.get(url, headers = self.httpheaders) as resp:
            resposta = await resp.json()
            await client.close()

            for sensor in resposta:
                if sensor["ultima_medicao_sensor"] != None:
                    sensores.append(
                        Sensor
                        (
                            self.chipid,
                            sensor["sensor_nome"],
                            sensor["apelido_canal"],
                            self.httpheaders
                        )
                    )
            return sensores

    async def initialize(self):
        self.sensores = await self._async_set_sensores()
        flemis = {}
        for sensor in self.sensores:
            flemis[sensor.apelido] = sensor

        self.sensores = flemis

    def get_sensor_names(self):
        return list(self.sensores.keys())

    def get_sensor_names_on(self, port: str):
        sensores = []
        for sensor in self.get_sensor_names():
            if sensor[-1] == port:
                sensores.append()
        return sensores

    def get_readings(self, nome_sensor):
        return asyncio.run(self.sensores[nome_sensor].get_leitura())

    def get_chipid(self):
        return self.chipid
